import { ModelOperations } from "@vscode/vscode-languagedetection";
import fs from "node:fs";

const dir = `${process.cwd()}/src/app/common/lang-detection`;

const modelOperations = new ModelOperations({
  modelJsonLoaderFunc: async () => {
    const response = await fs.promises.readFile(dir + "/model.json");
    return JSON.parse(response.toString());
  },
  weightsLoaderFunc: async () => {
    const response = await fs.promises.readFile(dir + "/weights.bin");
    return response.buffer;
  },
});

/**
 * Detects the programming language of the given content.
 *
 * @param content The content to detect the language of.
 */
export async function detectLanguage(content: string) {
  const languages = await modelOperations.runModel(content);
  return languages.length > 0 ? languages[0].languageId : "text";
}
